..
   Copyright (C) 2011,2012 Jaakko Luttinen

   This file is licensed under the MIT License. See LICENSE for a text of the
   license.


Nodes
=====

Stochastic nodes
----------------

Normal
++++++



Gaussian
++++++++

Gamma
+++++

Wishart
+++++++

Bernoulli
+++++++++

Categorical
+++++++++++

Binomial
++++++++

Multinomial
+++++++++++

Beta
++++

Dirichlet
+++++++++

Mixture
+++++++

Constant
++++++++


Deterministic nodes
-------------------

Dot product (of Gaussian variables)
+++++++++++++++++++++++++++++++++++

